@@ -32,9 +32,9 @@ ExampleWindow::ExampleWindow()
   // Note that the page_size value only makes a difference for
   // scrollbar widgets, and the highest value you'll get is actually
   // (upper - page_size).
-  m_adjustment(0.0, 0.0, 101.0, 0.1, 1.0, 1.0),
-  m_adjustment_digits(1.0, 0.0, 5.0),
-  m_adjustment_pagesize(1.0, 1.0, 101.0),
+  m_adjustment( Gtk::Adjustment::create(0.0, 0.0, 101.0, 0.1, 1.0, 1.0) ),
+  m_adjustment_digits( Gtk::Adjustment::create(1.0, 0.0, 5.0) ),
+  m_adjustment_pagesize( Gtk::Adjustment::create(1.0, 1.0, 101.0) ),
 
   m_VScale(m_adjustment),
   m_HScale(m_adjustment),
@@ -45,7 +45,7 @@ ExampleWindow::ExampleWindow()
   m_CheckButton("Display value on scale widgets", 0),
 
   // Reuse the same adjustment again.
-  // Notice how this causes the scales to always be updated 
+  // Notice how this causes the scales to always be updated
   // continuously when the scrollbar is moved.
   m_Scrollbar(m_adjustment),
 
@@ -54,11 +54,13 @@ ExampleWindow::ExampleWindow()
   set_title("range controls");
 
   //VScale:
+  m_VScale.set_update_policy(Gtk::UPDATE_CONTINUOUS);
   m_VScale.set_digits(1);
   m_VScale.set_value_pos(Gtk::POS_TOP);
   m_VScale.set_draw_value();
 
   //HScale:
+  m_HScale.set_update_policy(Gtk::UPDATE_CONTINUOUS);
   m_HScale.set_digits(1);
   m_HScale.set_value_pos(Gtk::POS_TOP);
   m_HScale.set_draw_value();
@@ -76,6 +78,7 @@ ExampleWindow::ExampleWindow()
   m_VBox_HScale.pack_start(m_HScale);
 
   //Scrollbar:
+  m_Scrollbar.set_update_policy(Gtk::UPDATE_CONTINUOUS);
   m_VBox_HScale.pack_start(m_Scrollbar);
 
   //CheckButton:
@@ -109,11 +112,38 @@ ExampleWindow::ExampleWindow()
       &ExampleWindow::on_menu_position), Gtk::POS_RIGHT));
   m_Menu_Position.append(*item);
 
+  m_VBox2.pack_start(
+    *Gtk::manage(new LabeledOptionMenu("Scale Value Position:",
+      m_Menu_Position)));
+
+
+  item = Gtk::manage(new Gtk::MenuItem("Continuous"));
+  item->signal_activate().connect(
+    sigc::bind(sigc::mem_fun(*this,
+      &ExampleWindow::on_menu_policy), Gtk::UPDATE_CONTINUOUS));
+  m_Menu_Policy.append(*item);
+
+  item = Gtk::manage(new Gtk::MenuItem("Discontinuous"));
+  item->signal_activate().connect(
+    sigc::bind(sigc::mem_fun(*this,
+      &ExampleWindow::on_menu_policy), Gtk::UPDATE_DISCONTINUOUS));
+  m_Menu_Policy.append(*item);
+
+  item = Gtk::manage(new Gtk::MenuItem("Delayed"));
+  item->signal_activate().connect(
+    sigc::bind(sigc::mem_fun(*this,
+      &ExampleWindow::on_menu_policy), Gtk::UPDATE_DELAYED));
+  m_Menu_Policy.append(*item);
+
+  m_VBox2.pack_start(
+    *Gtk::manage(new LabeledOptionMenu("Scale Update Policy:",
+      m_Menu_Policy)));
+
   //Digits:
   m_HBox_Digits.pack_start(
     *Gtk::manage(new Gtk::Label("Scale Digits:", 0)), Gtk::PACK_SHRINK);
   m_Scale_Digits.set_digits(0);
-  m_adjustment_digits.signal_value_changed().connect(sigc::mem_fun(*this,
+  m_adjustment_digits->signal_value_changed().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_adjustment1_value_changed));
   m_HBox_Digits.pack_start(m_Scale_Digits);
 
@@ -122,7 +152,7 @@ ExampleWindow::ExampleWindow()
     *Gtk::manage(new Gtk::Label("Scrollbar Page Size:", 0)),
     Gtk::PACK_SHRINK);
   m_Scale_PageSize.set_digits(0);
-  m_adjustment_pagesize.signal_value_changed().connect(sigc::mem_fun(*this,
+  m_adjustment_pagesize->signal_value_changed().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_adjustment2_value_changed));
   m_HBox_PageSize.pack_start(m_Scale_PageSize);
 
@@ -156,20 +186,26 @@ void ExampleWindow::on_menu_position(Gtk::PositionType postype)
   m_HScale.set_value_pos(postype);
 }
 
+void ExampleWindow::on_menu_policy(Gtk::UpdateType type)
+{
+  m_VScale.set_update_policy(type);
+  m_HScale.set_update_policy(type);
+}
+
 void ExampleWindow::on_adjustment1_value_changed()
 {
-  double val = m_adjustment_digits.get_value();
+  const double val = m_adjustment_digits->get_value();
   m_VScale.set_digits((int)val);
   m_HScale.set_digits((int)val);
 }
 
 void ExampleWindow::on_adjustment2_value_changed()
 {
-  double val = m_adjustment_pagesize.get_value();
-  m_adjustment.set_page_size(val);
-  m_adjustment.set_page_increment(val);
+  const double val = m_adjustment_pagesize->get_value();
+  m_adjustment->set_page_size(val);
+  m_adjustment->set_page_increment(val);
 
-  // Note that we don't have to emit the "changed" signal 
+  // Note that we don't have to emit the "changed" signal
   // because gtkmm does this for us.
 }
 
@@ -177,4 +213,3 @@ void ExampleWindow::on_button_quit()
 {
   hide();
 }
-
